@@ -853,9 +853,9 @@ def get_build_info() -> BuildInfo:
     """
 
     return BuildInfo(
-        version="0.6.1",
-        build="20/05/2022-17:29:34",
-        hash="0xEF57DA54",
+        version="0.7.0",
+        build="05/08/2022-10:49:12",
+        hash="0x95d6cf14",
         dirty=False
     )
 
