@@ -1285,7 +1285,7 @@ class QcmQrmDummyTransport(DummyTransport):
             if cmd_args[0] in self._acq_acquisitions[cmd_params[0]]:
                 sample_width = 12
                 max_sample_value = 2 ** (sample_width - 1) - 1
-                size = 2 ** 14 - 1
+                size = 2 ** 14
                 self._acq_acquisitions[cmd_params[0]][cmd_args[0]]["acq"]["scope"]["data"][0] = struct.pack(
                     "i" * size,
                     *[int(max_sample_value / size) * i for i in range(0, size)]
