@@ -553,6 +553,12 @@ class Cluster(ClusterScpi):
         _, funcs = self._present_at_init(slot)
         return gf.delete_acquisition(funcs, sequencer, name, all)
 
+    # --------------------------------------------------------------------------
+    @gf.copy_docstr(gf.delete_acquisition_data)
+    def delete_acquisition_data(self, slot: int, sequencer: int, name: str = "", all: bool = False) -> None:
+        _, funcs = self._present_at_init(slot)
+        return gf.delete_acquisition_data(funcs, sequencer, name, all)
+
     # -------------------------------------------------------------------------
     @gf.copy_docstr(gf.store_scope_acquisition)
     def store_scope_acquisition(self, slot: int, sequencer: int, name: str) -> None:
