@@ -242,6 +242,9 @@ List of sequencer status flag enums of type
 """
 
 
+# Maximum program length allowed
+MAX_PROGRAM_LENGTH = 10 * (128*1024*8 + 1024)
+
 # JSON schema to validate sequence dictionaries with
 QCM_SEQUENCE_JSON_SCHEMA = {
     "title": "Sequence container",
@@ -563,6 +566,40 @@ def check_sequencer_index(sequencer: int) -> None:
             "Sequencer index is out-of-range ({})".format(sequencer)
         )
 
+# ---------------------------------------------------------------------
+def _check_program_length(program: str) -> None:
+    """
+    Checks if the program length is above the limit. If it is, an
+    attempt is made to shorten the program by removing comments and
+    unnecessary whitespaces. If the program is still too large, a
+    Runtime error is raised.
+
+    Parameters
+    ----------
+    program : str
+        Sequence program to be updated to the device
+
+    Returns
+    ----------
+
+    Raises
+    ----------
+    RuntimeError
+        Too large program string.
+    """
+
+    if len(program.encode('utf-8')) > MAX_PROGRAM_LENGTH:
+        checked_program = re.sub(r'#.*|^\s*', '', program, 0, re.MULTILINE)
+        checked_program = re.sub(r'[^\S\r\n]+', ' ', checked_program)
+
+        if len(checked_program.encode('utf-8')) > MAX_PROGRAM_LENGTH:
+            raise RuntimeError(
+                                "Program length too large, expected something below {} bytes but got {} bytes.".format(MAX_PROGRAM_LENGTH, len(checked_program.encode('utf-8')))
+                            )
+        else:
+            return checked_program
+    else:
+        return program
 
 # ----------------------------------------------------------------------------
 def check_qrm_type(is_qrm_type: bool) -> None:
@@ -930,8 +967,9 @@ def set_sequencer_program(funcs: FuncRefs, sequencer: int, program: str) -> None
     """
 
     check_sequencer_index(sequencer)
+
     try:
-        funcs._set_sequencer_program(sequencer, program)
+        funcs._set_sequencer_program(sequencer, _check_program_length(program))
     except:
         print(funcs.get_assembler_log())
         raise
@@ -2316,6 +2354,36 @@ def delete_acquisition(
     check_sequencer_index(sequencer)
     funcs._delete_acq_acquisition(sequencer, "all" if all else name)
 
+# ----------------------------------------------------------------------------
+def delete_acquisition_data(
+    funcs: FuncRefs,
+    sequencer: int,
+    name: str = "",
+    all: bool = False
+) -> None:
+    """
+    Delete data from an acquisition specified by name in the acquisition list
+    of indexed sequencer or delete data in all acquisitions if `all` is True.
+
+    Parameters
+    ----------
+    sequencer : int
+        Sequencer index.
+    name : str
+        Weight name
+
+    Returns
+    ----------
+
+    Raises
+    ----------
+    NotImplementedError
+        Functionality not available on this module.
+    """
+
+    check_qrm_type(funcs.is_qrm_type())
+    check_sequencer_index(sequencer)
+    funcs._delete_acq_acquisition_data(sequencer, "all" if all else name)
 
 # ----------------------------------------------------------------------------
 def store_scope_acquisition(funcs: FuncRefs, sequencer: int, name: str) -> None:
